import { ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { LanguageDescription } from '@codemirror/language';
import { Extension } from '@codemirror/state';
import { EditorView } from '@codemirror/view';
import * as i0 from "@angular/core";
export type Theme = 'light' | 'dark' | Extension;
export type Setup = 'basic' | 'minimal' | null;
export declare class CodeEditor implements OnInit, OnDestroy, ControlValueAccessor {
    private _elementRef;
    /**
     * The document or shadow [root](https://codemirror.net/docs/ref/#view.EditorView.root)
     * that the view lives in.
     */
    root?: Document | ShadowRoot;
    /** Whether focus on the editor after init. */
    autoFocus: boolean;
    /** Editor's value. */
    get value(): string;
    set value(newValue: string);
    private _value;
    /** Editor's theme. */
    get theme(): Theme;
    set theme(value: Theme);
    private _theme;
    /** Editor's placecholder. */
    get placeholder(): string;
    set placeholder(value: string);
    private _placeholder;
    /** Whether the editor is disabled.  */
    disabled: boolean;
    /** Whether the editor is readonly. */
    get readonly(): boolean;
    set readonly(value: boolean);
    private _readonly;
    /** A binding that binds Tab to indentMore and Shift-Tab to indentLess. */
    get indentWithTab(): boolean;
    set indentWithTab(value: boolean);
    private _indentWithTab;
    /** Should be a string consisting either entirely of the same whitespace character. */
    get indentUnit(): string;
    set indentUnit(value: string);
    private _indentUnit;
    /** Whether this editor wraps lines. */
    get lineWrapping(): boolean;
    set lineWrapping(value: boolean);
    private _lineWrapping;
    /** Whether highlight the whitespace. */
    get highlightWhitespace(): boolean;
    set highlightWhitespace(value: boolean);
    private _highlightWhitespace;
    /**
     * An array of language descriptions for known
     * [language-data packages](https://github.com/codemirror/language-data/blob/main/src/language-data.ts).
     */
    languages: LanguageDescription[];
    /** Editor's language. You should set the `languages` prop at first. */
    get language(): string;
    set language(value: string);
    private _language;
    /**
     * The editor's built-in setup. The value can be set to
     * [`basic`](https://codemirror.net/docs/ref/#codemirror.basicSetup),
     * [`minimal`](https://codemirror.net/docs/ref/#codemirror.minimalSetup) or `null`.
     */
    get setup(): Setup;
    set setup(value: Setup);
    private _setup;
    /**
     * EditorState's [extensions](https://codemirror.net/docs/ref/#state.EditorStateConfig.extensions).
     */
    get extensions(): Extension[];
    set extensions(value: Extension[]);
    private _extensions;
    /** Event emitted when the editor's value changes. */
    change: EventEmitter<string>;
    /** Event emitted when focus on the editor. */
    focus: EventEmitter<void>;
    /** Event emitted when the editor has lost focus. */
    blur: EventEmitter<void>;
    view?: EditorView;
    private _onChange;
    private _onTouched;
    constructor(_elementRef: ElementRef<Element>);
    private _updateListener;
    private _themeConf;
    private _placeholderConf;
    private _disabledConf;
    private _readonlyConf;
    private _indentWithTabConf;
    private _indentUnitConf;
    private _lineWrappingConf;
    private _highlightWhitespaceConf;
    private _languageConf;
    private _getExtensions;
    private _dispatchEffects;
    reconfigure(): void;
    setValue(value: string): void;
    /** Sets language dynamically. */
    setLanguage(lang: string, onInit?: boolean): void;
    /** Find the language's extension by its name. Case insensitive. */
    findLanguage(name: string): LanguageDescription | null;
    ngOnInit(): void;
    ngOnDestroy(): void;
    writeValue(value: string): void;
    registerOnChange(fn: (value: string) => void): void;
    registerOnTouched(fn: () => void): void;
    setDisabledState(isDisabled: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CodeEditor, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CodeEditor, "code-editor", never, { "root": { "alias": "root"; "required": false; }; "autoFocus": { "alias": "autoFocus"; "required": false; }; "value": { "alias": "value"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "indentWithTab": { "alias": "indentWithTab"; "required": false; }; "indentUnit": { "alias": "indentUnit"; "required": false; }; "lineWrapping": { "alias": "lineWrapping"; "required": false; }; "highlightWhitespace": { "alias": "highlightWhitespace"; "required": false; }; "languages": { "alias": "languages"; "required": false; }; "language": { "alias": "language"; "required": false; }; "setup": { "alias": "setup"; "required": false; }; "extensions": { "alias": "extensions"; "required": false; }; }, { "change": "change"; "focus": "focus"; "blur": "blur"; }, never, never, true, never>;
    static ngAcceptInputType_autoFocus: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_readonly: unknown;
    static ngAcceptInputType_indentWithTab: unknown;
    static ngAcceptInputType_lineWrapping: unknown;
    static ngAcceptInputType_highlightWhitespace: unknown;
}
